@@ -603,7 +603,7 @@ def samplingVariantsForAmstc(net, m0, mf, log,sample_size,size_of_run, max_d, ma
                         break
             # align centroid and entire log with alignments
             if not bool_clustered:
-                alignment=alignments.apply(variants[l][0],centroid,c_m0,c_mf)
+                alignment=alignments.algorithm.apply(variants[l][0],centroid,c_m0,c_mf)
                 if alignment['cost']< 10000*((max_d+1)):
                     counter=-1
                     traces_of_clusters+=variants[l]
@@ -706,7 +706,7 @@ def samplingForAmstc(net, m0, mf, log,sample_size,size_of_run, max_d, max_t, m ,
                                     bool_clustered=True
                                     break
                         if not bool_clustered:
-                            alignment=alignments.apply(l,centroid,c_m0,c_mf)
+                            alignment=alignments.algorithm.apply(l,centroid,c_m0,c_mf)
                             if alignment['cost']< 10000*((max_d+1)):
                                 counter=-1
                                 traces_of_clusters.append(l)
